@@ -16,24 +16,25 @@
 
 from __future__ import print_function
 
-import os
-import sys
-import platform
 import argparse
+import os
+import platform
+import sys
 
 from yamllint import APP_DESCRIPTION, APP_NAME, APP_VERSION
+from yamllint import linter
 from yamllint.config import YamlLintConfig, YamlLintConfigError
 from yamllint.linter import PROBLEM_LEVELS
-from yamllint import linter
 
 
-def find_files_recursively(items):
+def find_files_recursively(items, conf):
     for item in items:
         if os.path.isdir(item):
             for root, dirnames, filenames in os.walk(item):
-                for filename in [f for f in filenames
-                                 if f.endswith(('.yml', '.yaml'))]:
-                    yield os.path.join(root, filename)
+                for f in filenames:
+                    filepath = os.path.join(root, f)
+                    if conf.is_yaml_file(filepath):
+                        yield filepath
         else:
             yield item
 
@@ -83,11 +84,43 @@ class Format(object):
         return line
 
 
+def show_problems(problems, file, args_format, no_warn):
+    max_level = 0
+    first = True
+
+    for problem in problems:
+        max_level = max(max_level, PROBLEM_LEVELS[problem.level])
+        if no_warn and (problem.level != 'error'):
+            continue
+        if args_format == 'parsable':
+            print(Format.parsable(problem, file))
+        elif args_format == 'colored' or \
+                (args_format == 'auto' and supports_color()):
+            if first:
+                print('\033[4m%s\033[0m' % file)
+                first = False
+            print(Format.standard_color(problem, file))
+        else:
+            if first:
+                print(file)
+                first = False
+            print(Format.standard(problem, file))
+
+    if not first and args_format != 'parsable':
+        print('')
+
+    return max_level
+
+
 def run(argv=None):
     parser = argparse.ArgumentParser(prog=APP_NAME,
                                      description=APP_DESCRIPTION)
-    parser.add_argument('files', metavar='FILE_OR_DIR', nargs='+',
-                        help='files to check')
+    files_group = parser.add_mutually_exclusive_group(required=True)
+    files_group.add_argument('files', metavar='FILE_OR_DIR', nargs='*',
+                             default=(),
+                             help='files to check')
+    files_group.add_argument('-', action='store_true', dest='stdin',
+                             help='read from standard input')
     config_group = parser.add_mutually_exclusive_group()
     config_group.add_argument('-c', '--config-file', dest='config_file',
                               action='store',
@@ -96,16 +129,17 @@ def run(argv=None):
                               action='store',
                               help='custom configuration (as YAML source)')
     parser.add_argument('-f', '--format',
-                        choices=('parsable', 'standard'), default='standard',
-                        help='format for parsing output')
+                        choices=('parsable', 'standard', 'colored', 'auto'),
+                        default='auto', help='format for parsing output')
     parser.add_argument('-s', '--strict',
                         action='store_true',
                         help='return non-zero exit code on warnings '
                              'as well as errors')
+    parser.add_argument('--no-warnings',
+                        action='store_true',
+                        help='output only error level problems')
     parser.add_argument('-v', '--version', action='version',
-                        version='%s %s' % (APP_NAME, APP_VERSION))
-
-    # TODO: read from stdin when no filename?
+                        version='{} {}'.format(APP_NAME, APP_VERSION))
 
     args = parser.parse_args(argv)
 
@@ -125,6 +159,10 @@ def run(argv=None):
             conf = YamlLintConfig(file=args.config_file)
         elif os.path.isfile('.yamllint'):
             conf = YamlLintConfig(file='.yamllint')
+        elif os.path.isfile('.yamllint.yaml'):
+            conf = YamlLintConfig(file='.yamllint.yaml')
+        elif os.path.isfile('.yamllint.yml'):
+            conf = YamlLintConfig(file='.yamllint.yml')
         elif os.path.isfile(user_global_config):
             conf = YamlLintConfig(file=user_global_config)
         else:
@@ -135,34 +173,28 @@ def run(argv=None):
 
     max_level = 0
 
-    for file in find_files_recursively(args.files):
+    for file in find_files_recursively(args.files, conf):
         filepath = file[2:] if file.startswith('./') else file
         try:
-            first = True
             with open(file) as f:
-                for problem in linter.run(f, conf, filepath):
-                    if args.format == 'parsable':
-                        print(Format.parsable(problem, file))
-                    elif supports_color():
-                        if first:
-                            print('\033[4m%s\033[0m' % file)
-                            first = False
-
-                        print(Format.standard_color(problem, file))
-                    else:
-                        if first:
-                            print(file)
-                            first = False
-
-                        print(Format.standard(problem, file))
-
-                    max_level = max(max_level, PROBLEM_LEVELS[problem.level])
-
-            if not first and args.format != 'parsable':
-                print('')
+                problems = linter.run(f, conf, filepath)
         except EnvironmentError as e:
             print(e, file=sys.stderr)
             sys.exit(-1)
+        prob_level = show_problems(problems, file, args_format=args.format,
+                                   no_warn=args.no_warnings)
+        max_level = max(max_level, prob_level)
+
+    # read yaml from stdin
+    if args.stdin:
+        try:
+            problems = linter.run(sys.stdin, conf, '')
+        except EnvironmentError as e:
+            print(e, file=sys.stderr)
+            sys.exit(-1)
+        prob_level = show_problems(problems, 'stdin', args_format=args.format,
+                                   no_warn=args.no_warnings)
+        max_level = max(max_level, prob_level)
 
     if max_level == PROBLEM_LEVELS['error']:
         return_code = 1
